import {Component, ElementRef, OnInit, ViewChild} from '@angular/core';
import {TopologyService} from '../topology.service';
import {OverAllService} from '../../overAll/overAll.service';
import {NzMessageService} from 'ng-zorro-antd';
import {pageSize} from '../../app.constants';
import {DatePipe} from '@angular/common';

declare var vis: any;

@Component({
    selector: 'smart-flow-trend',
    templateUrl: './flow-trend.component.html',
    styles: []
})
export class FlowTrendComponent implements OnInit {
    groupList;
    hostList;
    obj = {
        groupid:null,
        hostid: null,
        startTime: '',
        endTime: ''
    };

    //in
    inList = [];
    inPageNum = 1;
    inPageCount = pageSize;
    inTotalNum;

    //out
    outList = [];
    outPageNum = 1;
    outPageCount = pageSize;
    outTotalNum;

    constructor(private topologySer: TopologyService, private overAllSer: OverAllService,
                private message: NzMessageService,private dataPipe:DatePipe) {
    }

    ngOnInit() {
        this.getGroup();
        const today = new Date().getTime();
        this.obj.startTime = this.dataPipe.transform(today,"yyyy-MM-dd") + " 00:00:00";
        this.obj.endTime = this.dataPipe.transform(today,"yyyy-MM-dd") + " 23:59:59";
    }

    //获取分组
    getGroup() {
        this.overAllSer.getgroups({}).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.groupList = res.data;
                }
            }
        );
    }

    //查询主机
    onchange(e) {
        const data = {
            'groupids': [e],
            'hostExtend': {
                'superiorHostid': null
            }
        };
        this.overAllSer.findDetail(data).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.hostList = res.data;
                }
            }
        );
    }

    getEcharts() {
        const data = {
            itemid: '',
            endTime: this.obj.endTime,
            startTime: this.obj.startTime
        };
        this.topologySer.findTrendData(data).subscribe(
            (res) => {

            }
        );
    }

    //获取流量
    getList(e) {
        this.onchange(e);
        this.getInList();
        this.getOutList();
    }

    getListIO(){
        this.getInList();
        this.getOutList();
    }

    //进口流量
    getInList() {
        const data = {
            type: 'in',
            pageNum: '1',
            pageCount: '10',
            hostid: this.obj.hostid,
            startTime: this.obj.startTime,
            endTime: this.obj.endTime,
            groupid:this.obj.groupid
        };
        this.topologySer.findTrend(data).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.inList = res.data;
                } else {
                    this.message.warning(res.errMsg);
                }
            }
        );
    }

    //出口流量
    getOutList() {
        const data = {
            type: 'out',
            pageNum: '1',
            pageCount: '10',
            hostid: this.obj.hostid,
            startTime: this.obj.startTime,
            endTime: this.obj.endTime,
            groupid:this.obj.groupid
        };
        this.topologySer.findTrend(data).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.outList = res.data;
                } else {
                    this.message.warning(res.errMsg);
                }
            }
        );
    }

}
